pub struct MethodOverrides {
pub get: bool,
pub post: bool,
pub put: bool,
pub patch: bool,
pub delete: bool,
pub search: bool,
pub subscribe: bool,
pub connect: bool,
}Expand description
Configuration for which methods are overridden by a custom resource.
Used by ExtendedTableResource to know when to delegate to the table
vs. when to call the custom resource’s implementation.
Fields
get: boolOverride GET handler
post: boolOverride POST handler
put: boolOverride PUT handler
patch: boolOverride PATCH handler
delete: boolOverride DELETE handler
search: boolOverride SEARCH/query handler
subscribe: boolOverride SSE subscribe handler
connect: boolOverride WebSocket connect handler
Implementations