Resource execution hooks (pre/post/failure). Resource execution hooks — pre/post/failure hooks for request dispatch.
Hook types and configuration are defined here in yeti-types so they can be referenced by both yeti-sdk (which runs hooks) and yeti-router (which dispatches requests).
Structs
- Hook
Config - Hook configuration declared under
[package.metadata.app.hooks]in the app’sCargo.toml. - Hook
RunResult - Result of running a hook command.
Enums
- Hook
Event - The phase at which a hook fires relative to resource dispatch.